==> gcstar_1.6.2.orig.tar.gz: gcstar/lib/gcstar/GCLang/FR/GCModels/GCTVseries.pm <==
{
    package GCLang::FR::GCModels::GCTVseries;

    use utf8;
###################################################
#
#  Copyright 2005-2010 Christian Jodar
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use GCLang::GCLangUtils;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Collection de séries TV',
        Items => {0 => 'Série',
                  1 => 'Série',
                  X => 'Séries',
                  I1 => 'Une série',
                  D1 => 'La série',
                  DX => 'Les séries',
                  DD1 => 'De la série',
                  M1 => 'Cette série',
                  C1 => 'e série',
                  DA1 => 'e série',
                  DAX => 'e séries'},
        NewItem => 'Nouvelle série',
        Name => 'Nom',
        Season => 'Saison',
        Part => 'Partie',
        Episodes => 'Épisodes',
        FirstAired => 'Première diffusion',
        Time => 'Durée épisode',
        Producer => 'Producteur',
        Music => 'Musique',
     );
     importTranslation('Films');
}

1;

==> gcstar_1.7.1.orig.tar.gz: gcstar/lib/gcstar/GCLang/FR/GCModels/GCTVseries.pm <==
{
    package GCLang::FR::GCModels::GCTVseries;

    use utf8;
###################################################
#
#  Copyright 2005-2010 Christian Jodar
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
#
###################################################
    
    use strict;
    use GCLang::GCLangUtils;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Collection de séries TV',
        Items => {0 => 'Série',
                  1 => 'Série',
                  X => 'Séries',
                  I1 => 'Une série',
                  D1 => 'La série',
                  DX => 'Les séries',
                  DD1 => 'De la série',
                  M1 => 'Cette série',
                  C1 => 'e série',
                  DA1 => 'e série',
                  DAX => 'e séries'},
        NewItem => 'Nouvelle série',
        Name => 'Nom',
        Season => 'Saison',
        Part => 'Partie',
        Episodes => 'Épisodes',
        FirstAired => 'Première diffusion',
        Time => 'Durée épisode',
        Producer => 'Producteur',
        Music => 'Musique',
     );
     importTranslation('Films');
}

1;
